@@ -4,6 +4,7 @@ from functools import wraps
 
 from aiohttp import web
 from aiohttp.web import RouteTableDef
+from aiohttp.helpers import sentinel
 
 from dazl import AIOPartyClient
 
@@ -12,7 +13,11 @@ from .common import \
     without_return_value, \
     as_handler_invocation
 
-from ..api import AuthorizationLevel, IntegrationWebhookRoutes
+from ..api import \
+    AuthorizationLevel, \
+    IntegrationWebhookRoutes, \
+    IntegrationWebhookResponse, \
+    json_response
 
 from .log import LOG
 from .auth_handler import set_handler_auth
@@ -28,6 +33,46 @@ class WebhookRouteStatus(InvocationStatus):
     method: str
 
 
+def get_http_response(hook_response: 'IntegrationWebhookResponse'):
+    response = empty_success_response()  # type: web.Response
+
+    if hook_response.response is not None:
+        LOG.debug("Returning 'response' field as HTTP response. ")
+
+        response = hook_response.response
+
+    elif hook_response.json_response is not None:
+        LOG.debug("Returning 'json_response' field as HTTP response")
+
+        response = json_response(
+            data=hook_response.json_response,
+            status=hook_response.http_status)
+
+    elif hook_response.text_response is not None:
+        LOG.debug("Returning 'text_response' field as HTTP response")
+
+        response = web.Response(
+            text=hook_response.text_response,
+            content_type=hook_response.http_content_type,
+            status=hook_response.http_status)
+
+    elif hook_response.blob_response is not None:
+        LOG.debug("Returning 'blob_response' field as HTTP response")
+
+        response = web.Response(
+            body=hook_response.blob_response,
+            content_type=hook_response.http_content_type,
+            status=hook_response.http_status)
+
+    else:
+        LOG.debug("Returning default successful HTTP response")
+
+
+    LOG.debug('Webhook Response: %r', response)
+
+    return response
+
+
 class IntegrationWebhookContext(IntegrationWebhookRoutes):
 
     def __init__(self, queue: 'IntegrationDeferralQueue', client: 'AIOPartyClient'):
@@ -40,22 +85,15 @@ class IntegrationWebhookContext(IntegrationWebhookRoutes):
 
         @wraps(fn)
         async def wrapped(request):
-            hook_response = await fn(request)
-
-            if hook_response.response is None:
-                response = empty_success_response()
-            else:
-                response = hook_response.response
-
-            LOG.debug('Webhook Response: %r', response)
-
-            return response
+            return get_http_response(await fn(request))
 
         return wrapped
 
     def _notice_hook_route(self, url_path: str, method: str,
                            label: 'Optional[str]') -> 'WebhookRouteStatus':
 
+        LOG.debug('Registered hook (label: %s): %s %r', label, method, url_path)
+
         route_status = \
             WebhookRouteStatus(
                 index=len(self.routes),
